@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "24.0.2+12" },
-            { "jdk", "24.0.2" },
-            { "release", "24.0.2" },
+            { "full", "24+36" },
+            { "jdk", "24" },
+            { "release", "24" },
         };
     }
 }
